==> estateplat-common-1.2.4-20201120.075511-535-sources.jar: cn/gtmap/estateplat/model/server/core/XxgxSgaRxdb.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:zhengqi@gtmap.cn">zhengqi</a>
 * @version 1.0, 2020/11/19
 * @description 省级信息共享-省公安厅-人像比对查询接口
 */
@Table(name = "xxgx_sga_rxdb")
public class XxgxSgaRxdb {
    @Id
    private String rxdbid;//主键
    private String sfzh;//身份证号码
    private String xm;//姓名
    private String proid;//项目ID
    private String qlrid;//权利人ID
    private String exception;//异常信息
    private String exist;//是否存在
    private Double verify;//相似度

    public String getRxdbid() {
        return rxdbid;
    }

    public void setRxdbid(String rxdbid) {
        this.rxdbid = rxdbid;
    }

    public String getSfzh() {
        return sfzh;
    }

    public void setSfzh(String sfzh) {
        this.sfzh = sfzh;
    }

    public String getXm() {
        return xm;
    }

    public void setXm(String xm) {
        this.xm = xm;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getQlrid() {
        return qlrid;
    }

    public void setQlrid(String qlrid) {
        this.qlrid = qlrid;
    }

    public String getException() {
        return exception;
    }

    public void setException(String exception) {
        this.exception = exception;
    }

    public String getExist() {
        return exist;
    }

    public void setExist(String exist) {
        this.exist = exist;
    }

    public Double getVerify() {
        return verify;
    }

    public void setVerify(Double verify) {
        this.verify = verify;
    }
}

==> estateplat-common-1.2.4-20240702.040150-1240-sources.jar: cn/gtmap/estateplat/model/server/core/XxgxSgaRxdb.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;

/**
 * @author <a href="mailto:zhengqi@gtmap.cn">zhengqi</a>
 * @version 1.0, 2020/11/19
 * @description 省级信息共享-省公安厅-人像比对查询接口
 */
@Table(name = "xxgx_sga_rxdb")
public class XxgxSgaRxdb {
    @Id
    private String rxdbid;//主键
    private String sfzh;//身份证号码
    private String xm;//姓名
    private String proid;//项目ID
    private String qlrid;//权利人ID
    private String exception;//异常信息
    private String exist;//是否存在
    private Double verify;//相似度
    private String imgpath;//图片地址

    public String getRxdbid() {
        return rxdbid;
    }

    public void setRxdbid(String rxdbid) {
        this.rxdbid = rxdbid;
    }

    public String getSfzh() {
        return sfzh;
    }

    public void setSfzh(String sfzh) {
        this.sfzh = sfzh;
    }

    public String getXm() {
        return xm;
    }

    public void setXm(String xm) {
        this.xm = xm;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getQlrid() {
        return qlrid;
    }

    public void setQlrid(String qlrid) {
        this.qlrid = qlrid;
    }

    public String getException() {
        return exception;
    }

    public void setException(String exception) {
        this.exception = exception;
    }

    public String getExist() {
        return exist;
    }

    public void setExist(String exist) {
        this.exist = exist;
    }

    public Double getVerify() {
        return verify;
    }

    public void setVerify(Double verify) {
        this.verify = verify;
    }

    public String getImgpath() {
        return imgpath;
    }

    public void setImgpath(String imgpath) {
        this.imgpath = imgpath;
    }
}
